Class: Google::Apis::AccessapprovalV1::AccessLocations

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/accessapproval_v1/classes.rb,
lib/google/apis/accessapproval_v1/representations.rb,
lib/google/apis/accessapproval_v1/representations.rb

Overview

Physical assigned office and physical location of the Google administrator performing the access.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AccessLocations

Returns a new instance of AccessLocations.



224
225
226
# File 'lib/google/apis/accessapproval_v1/classes.rb', line 224

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#principal_office_countryString

The "home office" location of the Google administrator. A two-letter country code (ISO 3166-1 alpha-2), such as "US", "DE" or "GB" or a region code. In some limited situations Google systems may refer refer to a region code instead of a country code. Possible Region Codes: * ASI: Asia * EUR: Europe * OCE: Oceania * AFR: Africa * NAM: North America * SAM: South America * ANT: Antarctica * ANY: Any location Corresponds to the JSON property principalOfficeCountry

Returns:

  • (String)


212
213
214
# File 'lib/google/apis/accessapproval_v1/classes.rb', line 212

def principal_office_country
  @principal_office_country
end

#principal_physical_location_countryString

Physical location of the Google administrator at the time of the access. A two- letter country code (ISO 3166-1 alpha-2), such as "US", "DE" or "GB" or a region code. In some limited situations Google systems may refer refer to a region code instead of a country code. Possible Region Codes: * ASI: Asia * EUR: Europe * OCE: Oceania * AFR: Africa * NAM: North America * SAM: South America * ANT: Antarctica * ANY: Any location Corresponds to the JSON property principalPhysicalLocationCountry

Returns:

  • (String)


222
223
224
# File 'lib/google/apis/accessapproval_v1/classes.rb', line 222

def principal_physical_location_country
  @principal_physical_location_country
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



229
230
231
232
# File 'lib/google/apis/accessapproval_v1/classes.rb', line 229

def update!(**args)
  @principal_office_country = args[:principal_office_country] if args.key?(:principal_office_country)
  @principal_physical_location_country = args[:principal_physical_location_country] if args.key?(:principal_physical_location_country)
end