Class: Google::Apis::AccessapprovalV1::ApprovalRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/accessapproval_v1/classes.rb,
lib/google/apis/accessapproval_v1/representations.rb,
lib/google/apis/accessapproval_v1/representations.rb

Overview

A request for the customer to approve access to a resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ApprovalRequest

Returns a new instance of ApprovalRequest.



327
328
329
# File 'lib/google/apis/accessapproval_v1/classes.rb', line 327

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#approveGoogle::Apis::AccessapprovalV1::ApproveDecision

A decision that has been made to approve access to a resource. Corresponds to the JSON property approve



267
268
269
# File 'lib/google/apis/accessapproval_v1/classes.rb', line 267

def approve
  @approve
end

#dismissGoogle::Apis::AccessapprovalV1::DismissDecision

A decision that has been made to dismiss an approval request. Corresponds to the JSON property dismiss



272
273
274
# File 'lib/google/apis/accessapproval_v1/classes.rb', line 272

def dismiss
  @dismiss
end

#nameString

The resource name of the request. Format is "projects|folders|organizations/ id/approvalRequests/approval_request". Corresponds to the JSON property name

Returns:

  • (String)


278
279
280
# File 'lib/google/apis/accessapproval_v1/classes.rb', line 278

def name
  @name
end

#request_timeString

The time at which approval was requested. Corresponds to the JSON property requestTime

Returns:

  • (String)


283
284
285
# File 'lib/google/apis/accessapproval_v1/classes.rb', line 283

def request_time
  @request_time
end

#requested_augmented_infoGoogle::Apis::AccessapprovalV1::AugmentedInfo

This field contains the augmented information of the request. Requires augmented administrative access to be enabled. Corresponds to the JSON property requestedAugmentedInfo



289
290
291
# File 'lib/google/apis/accessapproval_v1/classes.rb', line 289

def requested_augmented_info
  @requested_augmented_info
end

#requested_durationString

The requested access duration. Corresponds to the JSON property requestedDuration

Returns:

  • (String)


294
295
296
# File 'lib/google/apis/accessapproval_v1/classes.rb', line 294

def requested_duration
  @requested_duration
end

#requested_expirationString

The original requested expiration for the approval. Calculated by adding the requested_duration to the request_time. Corresponds to the JSON property requestedExpiration

Returns:

  • (String)


300
301
302
# File 'lib/google/apis/accessapproval_v1/classes.rb', line 300

def requested_expiration
  @requested_expiration
end

#requested_locationsGoogle::Apis::AccessapprovalV1::AccessLocations

Physical assigned office and physical location of the Google administrator performing the access. Corresponds to the JSON property requestedLocations



306
307
308
# File 'lib/google/apis/accessapproval_v1/classes.rb', line 306

def requested_locations
  @requested_locations
end

#requested_reasonGoogle::Apis::AccessapprovalV1::AccessReason

The access reason for which approval is being requested. Corresponds to the JSON property requestedReason



311
312
313
# File 'lib/google/apis/accessapproval_v1/classes.rb', line 311

def requested_reason
  @requested_reason
end

#requested_resource_nameString

The resource for which approval is being requested. The format of the resource name is defined at https://cloud.google.com/apis/design/resource_names. The resource name here may either be a "full" resource name (e.g. "//library. googleapis.com/shelves/shelf1/books/book2") or a "relative" resource name (e.g. "shelves/shelf1/books/book2") as described in the resource name specification. Corresponds to the JSON property requestedResourceName

Returns:

  • (String)


320
321
322
# File 'lib/google/apis/accessapproval_v1/classes.rb', line 320

def requested_resource_name
  @requested_resource_name
end

#requested_resource_propertiesGoogle::Apis::AccessapprovalV1::ResourceProperties

The properties associated with the resource of the request. Corresponds to the JSON property requestedResourceProperties



325
326
327
# File 'lib/google/apis/accessapproval_v1/classes.rb', line 325

def requested_resource_properties
  @requested_resource_properties
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



332
333
334
335
336
337
338
339
340
341
342
343
344
# File 'lib/google/apis/accessapproval_v1/classes.rb', line 332

def update!(**args)
  @approve = args[:approve] if args.key?(:approve)
  @dismiss = args[:dismiss] if args.key?(:dismiss)
  @name = args[:name] if args.key?(:name)
  @request_time = args[:request_time] if args.key?(:request_time)
  @requested_augmented_info = args[:requested_augmented_info] if args.key?(:requested_augmented_info)
  @requested_duration = args[:requested_duration] if args.key?(:requested_duration)
  @requested_expiration = args[:requested_expiration] if args.key?(:requested_expiration)
  @requested_locations = args[:requested_locations] if args.key?(:requested_locations)
  @requested_reason = args[:requested_reason] if args.key?(:requested_reason)
  @requested_resource_name = args[:requested_resource_name] if args.key?(:requested_resource_name)
  @requested_resource_properties = args[:requested_resource_properties] if args.key?(:requested_resource_properties)
end