Class: Google::Apis::AccessapprovalV1::ApproveDecision

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/accessapproval_v1/classes.rb,
lib/google/apis/accessapproval_v1/representations.rb,
lib/google/apis/accessapproval_v1/representations.rb

Overview

A decision that has been made to approve access to a resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ApproveDecision

Returns a new instance of ApproveDecision.



402
403
404
# File 'lib/google/apis/accessapproval_v1/classes.rb', line 402

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#approve_timeString

The time at which approval was granted. Corresponds to the JSON property approveTime

Returns:

  • (String)


373
374
375
# File 'lib/google/apis/accessapproval_v1/classes.rb', line 373

def approve_time
  @approve_time
end

#auto_approvedBoolean Also known as: auto_approved?

True when the request has been auto-approved. Corresponds to the JSON property autoApproved

Returns:

  • (Boolean)


378
379
380
# File 'lib/google/apis/accessapproval_v1/classes.rb', line 378

def auto_approved
  @auto_approved
end

#expire_timeString

The time at which the approval expires. Corresponds to the JSON property expireTime

Returns:

  • (String)


384
385
386
# File 'lib/google/apis/accessapproval_v1/classes.rb', line 384

def expire_time
  @expire_time
end

#invalidate_timeString

If set, denotes the timestamp at which the approval is invalidated. Corresponds to the JSON property invalidateTime

Returns:

  • (String)


389
390
391
# File 'lib/google/apis/accessapproval_v1/classes.rb', line 389

def invalidate_time
  @invalidate_time
end

#policy_approvedBoolean Also known as: policy_approved?

True when the request has been approved by the customer's defined policy. Corresponds to the JSON property policyApproved

Returns:

  • (Boolean)


394
395
396
# File 'lib/google/apis/accessapproval_v1/classes.rb', line 394

def policy_approved
  @policy_approved
end

#signature_infoGoogle::Apis::AccessapprovalV1::SignatureInfo

Information about the digital signature of the resource. Corresponds to the JSON property signatureInfo



400
401
402
# File 'lib/google/apis/accessapproval_v1/classes.rb', line 400

def signature_info
  @signature_info
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



407
408
409
410
411
412
413
414
# File 'lib/google/apis/accessapproval_v1/classes.rb', line 407

def update!(**args)
  @approve_time = args[:approve_time] if args.key?(:approve_time)
  @auto_approved = args[:auto_approved] if args.key?(:auto_approved)
  @expire_time = args[:expire_time] if args.key?(:expire_time)
  @invalidate_time = args[:invalidate_time] if args.key?(:invalidate_time)
  @policy_approved = args[:policy_approved] if args.key?(:policy_approved)
  @signature_info = args[:signature_info] if args.key?(:signature_info)
end