Class: Google::Apis::AccessapprovalV1::AugmentedInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/accessapproval_v1/classes.rb,
lib/google/apis/accessapproval_v1/representations.rb,
lib/google/apis/accessapproval_v1/representations.rb

Overview

This field contains the augmented information of the request. Requires augmented administrative access to be enabled.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AugmentedInfo

Returns a new instance of AugmentedInfo.



428
429
430
# File 'lib/google/apis/accessapproval_v1/classes.rb', line 428

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#commandString

For command-line tools, the full command-line exactly as entered by the actor without adding any additional characters (such as quotation marks). Corresponds to the JSON property command

Returns:

  • (String)


426
427
428
# File 'lib/google/apis/accessapproval_v1/classes.rb', line 426

def command
  @command
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



433
434
435
# File 'lib/google/apis/accessapproval_v1/classes.rb', line 433

def update!(**args)
  @command = args[:command] if args.key?(:command)
end