Class: Google::Apis::AccessapprovalV1::DismissDecision

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/accessapproval_v1/classes.rb,
lib/google/apis/accessapproval_v1/representations.rb,
lib/google/apis/accessapproval_v1/representations.rb

Overview

A decision that has been made to dismiss an approval request.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DismissDecision

Returns a new instance of DismissDecision.



487
488
489
# File 'lib/google/apis/accessapproval_v1/classes.rb', line 487

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dismiss_timeString

The time at which the approval request was dismissed. Corresponds to the JSON property dismissTime

Returns:

  • (String)


477
478
479
# File 'lib/google/apis/accessapproval_v1/classes.rb', line 477

def dismiss_time
  @dismiss_time
end

#implicitBoolean Also known as: implicit?

This field will be true if the ApprovalRequest was implicitly dismissed due to inaction by the access approval approvers (the request is not acted on by the approvers before the exiration time). Corresponds to the JSON property implicit

Returns:

  • (Boolean)


484
485
486
# File 'lib/google/apis/accessapproval_v1/classes.rb', line 484

def implicit
  @implicit
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



492
493
494
495
# File 'lib/google/apis/accessapproval_v1/classes.rb', line 492

def update!(**args)
  @dismiss_time = args[:dismiss_time] if args.key?(:dismiss_time)
  @implicit = args[:implicit] if args.key?(:implicit)
end