Class: Google::Apis::AccessapprovalV1::EnrolledService
- Inherits:
-
Object
- Object
- Google::Apis::AccessapprovalV1::EnrolledService
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/accessapproval_v1/classes.rb,
lib/google/apis/accessapproval_v1/representations.rb,
lib/google/apis/accessapproval_v1/representations.rb
Overview
Represents the enrollment of a cloud resource into a specific service.
Instance Attribute Summary collapse
-
#cloud_product ⇒ String
The product for which Access Approval will be enrolled.
-
#enrollment_level ⇒ String
The enrollment level of the service.
Instance Method Summary collapse
-
#initialize(**args) ⇒ EnrolledService
constructor
A new instance of EnrolledService.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ EnrolledService
Returns a new instance of EnrolledService.
572 573 574 |
# File 'lib/google/apis/accessapproval_v1/classes.rb', line 572 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cloud_product ⇒ String
The product for which Access Approval will be enrolled. Allowed values are listed below (case-sensitive): * all * GA * Access Context Manager * Anthos Identity Service * AlloyDB for PostgreSQL * Apigee * Application Integration * App Hub * Artifact Registry * Anthos Service Mesh * Access Transparency * BigQuery * Certificate Authority Service * Cloud Bigtable * CCAI Assist and Knowledge * Cloud Dataflow * Cloud Dataproc * CEP Security Gateway * Compliance Evaluation Service * Cloud Firestore * Cloud Healthcare API * Chronicle * Cloud AI Companion Gateway - Titan * Google Cloud Armor * Cloud Asset Inventory * Cloud Asset Search * Cloud Deploy * Cloud DNS * Cloud Latency * Cloud Memorystore for Redis * CloudNet Control * Cloud Riptide * Cloud Tasks * Cloud Trace * Cloud Data Transfer * Cloud Composer * Integration Connectors * Contact Center AI Insights * Cloud Pub/Sub * Cloud Run * Resource Manager * Cloud Spanner * Database Center * Cloud Dataform * Cloud Data Fusion
- Dataplex * Dialogflow Customer Experience Edition * Cloud DLP * Document AI * Edge Container * Edge Network * Cloud EKM * Eventarc * Firebase Data Connect * Firebase Rules * App Engine * Cloud Build * Compute Engine * Cloud Functions ( 2nd Gen) * Cloud Filestore * Cloud Interconnect * Cloud NetApp Volumes * Cloud Storage * Generative AI App Builder * Google Kubernetes Engine * Backup for GKE API * GKE Connect * GKE Hub * Hoverboard * Cloud HSM * Cloud Identity and Access Management * Cloud Identity-Aware Proxy * Infrastructure Manager * Identity Storage Service * Key Access Justifications * Cloud Key Management Service * Cloud Logging * Looker (Google Cloud core) * Looker Studio * Management Hub * Model Armor * Cloud Monitoring * Cloud NAT * Connectivity Hub
- External passthrough Network Load Balancer * OIDC One * Organization Policy Service * Org Lifecycle * Persistent Disk * Parameter Manager * Private Services Access * Regional Internal Application Load Balancer * Storage Batch Operations * Cloud Security Command Center * Secure Source Manager * Seeker * Service Provisioning * Speaker ID * Secret Manager * Cloud SQL * Cloud Speech- to-Text * Traffic Director * Cloud Text-to-Speech * USPS Andromeda * Vertex AI
- Virtual Private Cloud (VPC) * VPC Access * VPC Service Controls Troubleshooter * VPC virtnet * Cloud Workstations * Web Risk Note: These values are supported as input for legacy purposes, but will not be returned from the API. * all * ga-only * appengine.googleapis.com * artifactregistry. googleapis.com * bigquery.googleapis.com * bigtable.googleapis.com * container. googleapis.com * cloudkms.googleapis.com * cloudresourcemanager.googleapis.com
- cloudsql.googleapis.com * compute.googleapis.com * dataflow.googleapis.com *
dataproc.googleapis.com * dlp.googleapis.com * iam.googleapis.com * logging.
googleapis.com * orgpolicy.googleapis.com * pubsub.googleapis.com * spanner.
googleapis.com * secretmanager.googleapis.com * speakerid.googleapis.com *
storage.googleapis.com Calls to UpdateAccessApprovalSettings using 'all' or
any of the XXX.googleapis.com will be translated to the associated product
name ('all', 'App Engine', etc.). Note: 'all' will enroll the resource in all
products supported at both 'GA' and 'Preview' levels. More information about
levels of support is available at https://cloud.google.com/access-approval/
docs/supported-services
Corresponds to the JSON property
cloudProduct
565 566 567 |
# File 'lib/google/apis/accessapproval_v1/classes.rb', line 565 def cloud_product @cloud_product end |
#enrollment_level ⇒ String
The enrollment level of the service.
Corresponds to the JSON property enrollmentLevel
570 571 572 |
# File 'lib/google/apis/accessapproval_v1/classes.rb', line 570 def enrollment_level @enrollment_level end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
577 578 579 580 |
# File 'lib/google/apis/accessapproval_v1/classes.rb', line 577 def update!(**args) @cloud_product = args[:cloud_product] if args.key?(:cloud_product) @enrollment_level = args[:enrollment_level] if args.key?(:enrollment_level) end |