Class: Google::Apis::AccessapprovalV1::ResourceProperties

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/accessapproval_v1/classes.rb,
lib/google/apis/accessapproval_v1/representations.rb,
lib/google/apis/accessapproval_v1/representations.rb

Overview

The properties associated with the resource of the request.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ResourceProperties

Returns a new instance of ResourceProperties.



632
633
634
# File 'lib/google/apis/accessapproval_v1/classes.rb', line 632

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#excludes_descendantsBoolean Also known as: excludes_descendants?

Whether an approval will exclude the descendants of the resource being requested. Corresponds to the JSON property excludesDescendants

Returns:

  • (Boolean)


629
630
631
# File 'lib/google/apis/accessapproval_v1/classes.rb', line 629

def excludes_descendants
  @excludes_descendants
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



637
638
639
# File 'lib/google/apis/accessapproval_v1/classes.rb', line 637

def update!(**args)
  @excludes_descendants = args[:excludes_descendants] if args.key?(:excludes_descendants)
end