Class: Google::Apis::AccessapprovalV1::SignatureInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/accessapproval_v1/classes.rb,
lib/google/apis/accessapproval_v1/representations.rb,
lib/google/apis/accessapproval_v1/representations.rb

Overview

Information about the digital signature of the resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SignatureInfo

Returns a new instance of SignatureInfo.



678
679
680
# File 'lib/google/apis/accessapproval_v1/classes.rb', line 678

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#customer_kms_key_versionString

The resource name of the customer CryptoKeyVersion used for signing. Corresponds to the JSON property customerKmsKeyVersion

Returns:

  • (String)


649
650
651
# File 'lib/google/apis/accessapproval_v1/classes.rb', line 649

def customer_kms_key_version
  @customer_kms_key_version
end

#google_key_algorithmString

The hashing algorithm used for signature verification. It will only be present in the case of Google managed keys. Corresponds to the JSON property googleKeyAlgorithm

Returns:

  • (String)


655
656
657
# File 'lib/google/apis/accessapproval_v1/classes.rb', line 655

def google_key_algorithm
  @google_key_algorithm
end

#google_public_key_pemString

The public key for the Google default signing, encoded in PEM format. The signature was created using a private key which may be verified using this public key. Corresponds to the JSON property googlePublicKeyPem

Returns:

  • (String)


662
663
664
# File 'lib/google/apis/accessapproval_v1/classes.rb', line 662

def google_public_key_pem
  @google_public_key_pem
end

#serialized_approval_requestString

The ApprovalRequest that is serialized without the SignatureInfo message field. This data is used with the hashing algorithm to generate the digital signature, and it can be used for signature verification. Corresponds to the JSON property serializedApprovalRequest NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


670
671
672
# File 'lib/google/apis/accessapproval_v1/classes.rb', line 670

def serialized_approval_request
  @serialized_approval_request
end

#signatureString

The digital signature. Corresponds to the JSON property signature NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


676
677
678
# File 'lib/google/apis/accessapproval_v1/classes.rb', line 676

def signature
  @signature
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



683
684
685
686
687
688
689
# File 'lib/google/apis/accessapproval_v1/classes.rb', line 683

def update!(**args)
  @customer_kms_key_version = args[:customer_kms_key_version] if args.key?(:customer_kms_key_version)
  @google_key_algorithm = args[:google_key_algorithm] if args.key?(:google_key_algorithm)
  @google_public_key_pem = args[:google_public_key_pem] if args.key?(:google_public_key_pem)
  @serialized_approval_request = args[:serialized_approval_request] if args.key?(:serialized_approval_request)
  @signature = args[:signature] if args.key?(:signature)
end